@@ -148,6 +148,15 @@ def main():
         help="Maimum number of slurm jobs that will be running at any given time (if slurm is used as backend).",
     )
 
+    parser_run.add_argument(
+        "--slurm-args",
+        type=str,
+        action=env_default("EXPERIMENTS_SLURM_ARGS"),
+        required=False,
+        default=None,
+        help="Additional arguments to pass to sbatch (if slurm is used as backend).",
+    )
+
     parser_run.add_argument(
         "--eventstream-host-ip",
         type=str,
