@@ -19,6 +19,7 @@ from .base import (
 from .label_repair import LabelRepairScenario
 from .data_discard import DataDiscardScenario
 from .compute_time import ComputeTimeScenario
+from .marginal_contribution import MarginalContributionScenario
 
 __all__ = [
     "Scenario",
@@ -40,4 +41,5 @@ __all__ = [
     "LabelRepairScenario",
     "DataDiscardScenario",
     "ComputeTimeScenario",
+    "MarginalContributionScenario",
 ]
