@@ -13,11 +13,11 @@ from datascope.importance.common import (
 from datascope.importance.importance import Importance
 from datascope.importance.shapley import ShapleyImportance
 from datetime import timedelta
+from numpy.typing import NDArray
 from time import process_time_ns
 from typing import Any, Iterable, List, Optional, Union, Dict
 
 from .base import attribute
-from ..baselines.influence.importance import InfluenceImportance
 from .datascope_scenario import (
     DatascopeScenario,
     RepairMethod,
@@ -169,8 +169,8 @@ class LabelRepairScenario(DatascopeScenario, id="label-repair"):
         )
 
         # Compute sensitive feature groupings.
-        groupings_val: Optional[np.ndarray] = None
-        groupings_test: Optional[np.ndarray] = None
+        groupings_val: Optional[NDArray] = None
+        groupings_test: Optional[NDArray] = None
         if isinstance(dataset, BiasedNoisyLabelDataset):
             groupings_val = compute_groupings(dataset.X_val, dataset.sensitive_feature)
             groupings_test = compute_groupings(dataset.X_test, dataset.sensitive_feature)
@@ -276,6 +276,8 @@ class LabelRepairScenario(DatascopeScenario, id="label-repair"):
         if self.method == RepairMethod.RANDOM:
             importances = list(random.rand(n_units))
         elif self.method == RepairMethod.INFLUENCE:
+            from ..baselines.influence.importance import InfluenceImportance
+
             dataset_f = dataset.apply(pipeline)
             dataset_dirty_f = dataset_dirty.apply(pipeline)
             importance = InfluenceImportance()
